@@ -50,15 +50,12 @@ class NoteShared::NoteAlarmDialogPrivate
 {
 public:
     NoteAlarmDialogPrivate()
-        : m_atDate(nullptr)
-        , m_atTime(nullptr)
-        , m_buttons(nullptr)
     {
     }
 
-    KDateComboBox *m_atDate;
-    KTimeComboBox *m_atTime;
-    QButtonGroup *m_buttons;
+    KDateComboBox *m_atDate = nullptr;
+    KTimeComboBox *m_atTime = nullptr;
+    QButtonGroup *m_buttons = nullptr;
 };
 
 NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
@@ -66,9 +63,8 @@ NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     , d(new NoteShared::NoteAlarmDialogPrivate)
 {
     setWindowTitle(caption);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -103,7 +99,7 @@ NoteAlarmDialog::NoteAlarmDialog(const QString &caption, QWidget *parent)
     layout->addWidget(at);
     d->m_buttons->addButton(label_at, 1);
 
-    connect(d->m_buttons, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &NoteAlarmDialog::slotButtonChanged);
+    connect(d->m_buttons, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &NoteAlarmDialog::slotButtonChanged);
     connect(okButton, &QPushButton::clicked, this, &NoteAlarmDialog::accept);
     d->m_buttons->button(0)->setChecked(true);
     slotButtonChanged(d->m_buttons->checkedId());
